Skip to contents

Downloads the Darwin Core tables produced by format_to_dc() from SharePoint, builds a Darwin Core Archive zip with an EML file, and uploads the archive back to SharePoint.

Usage

format_to_DC_archive()

Value

Invisible list with paths to the archive and EML.