Creates a simple EML list for the MareChiara dataset using the supplied event table to derive the date range.
Value
A list suitable for EML::write_eml().
Creates a simple EML list for the MareChiara dataset using the supplied event table to derive the date range.
A list suitable for EML::write_eml().