Loads environment variables from .env file if it exists. This function should be called before reading configuration to ensure dotenv variables are available.
Loads environment variables from .env file if it exists. This function should be called before reading configuration to ensure dotenv variables are available.