This function renders the Quarto report using the preprocessed survey data. It downloads the latest preprocessed data from SharePoint and renders the report to HTML format, saving it in the working directory.
This function renders the Quarto report using the preprocessed survey data. It downloads the latest preprocessed data from SharePoint and renders the report to HTML format, saving it in the working directory.