Downloads the Darwin Core tables produced by format_to_dc() from SharePoint,
builds a Darwin Core Archive zip with an EML file, and uploads the archive
back to SharePoint.
Downloads the Darwin Core tables produced by format_to_dc() from SharePoint,
builds a Darwin Core Archive zip with an EML file, and uploads the archive
back to SharePoint.